import Fuse from 'fuse.js';
import { BaseSearchStrategy } from './base-strategy.js';
/**
 * PostgreSQL search strategy - supports both database-level and client-side fuzzy search
 */
export class PostgreSQLFuzzyStrategy extends BaseSearchStrategy {
    pgPool;
    project;
    constructor(config, pgPool, project) {
        super(config);
        this.pgPool = pgPool;
        this.project = project;
    }
    canUseDatabase() {
        return this.config.useDatabaseSearch;
    }
    async searchDatabase(query, threshold, project) {
        const client = await this.pgPool.connect();
        try {
            // Use provided project parameter or fall back to constructor project
            const searchProject = project || this.project;
            const result = await client.query(`
        SELECT e.*,
               GREATEST(
                 similarity(e.name, $1),
                 similarity(e.entity_type, $1),
                 similarity(e.observations::text, $1),
                 similarity(e.tags::text, $1)
               ) as relevance_score
        FROM entities e
        WHERE e.project = $3
          AND (similarity(e.name, $1) > $2
               OR similarity(e.entity_type, $1) > $2
               OR similarity(e.observations::text, $1) > $2
               OR similarity(e.tags::text, $1) > $2)
        ORDER BY relevance_score DESC
        LIMIT 100
      `, [query, threshold, searchProject]);
            return result.rows.map(row => ({
                name: row.name,
                entityType: row.entity_type,
                observations: row.observations || [],
                tags: row.tags || []
            }));
        }
        finally {
            client.release();
        }
    }
    searchClientSide(entities, query) {
        const fuseOptions = {
            threshold: this.config.threshold,
            distance: 100,
            includeScore: true,
            keys: ['name', 'entityType', 'observations', 'tags'],
            ...this.config.fuseOptions
        };
        const fuse = new Fuse(entities, fuseOptions);
        const results = fuse.search(query);
        return results.map(result => result.item);
    }
}
//# sourceMappingURL=postgresql-strategy.js.map